@@ -1,19 +1,18 @@
-#coding:utf-8
-'''
-Модуль, реализущий работу с контекстом выполнения операции
-++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-'''
-#author: akvarats
-import datetime
-import json
-from decimal import Decimal
+# coding: utf-8
+u""""Модуль, реализущий работу с контекстом выполнения операции."""
 
-from django.utils.encoding import force_unicode
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
+from __future__ import absolute_import
+import json
+import datetime
+from decimal import Decimal
+from logging import getLogger
+
+from django.utils.encoding import force_str
+from m3_django_compat import get_request_params
+import six
+
+
+logger = getLogger('django')
 
 
 def _date2str(*args):
@@ -151,7 +150,7 @@ _datetime_parser = _make_datetime_parser(lambda x: x, formats=(
     ('%d.%m.%Y', 10),
     ('%H:%M:%S', 8),
     ('%H:%M', 5),
-)),
+))
 
 
 _date_parser = _make_datetime_parser(
@@ -172,8 +171,8 @@ _time_parser = _make_datetime_parser(
 
 
 _PARSERS = {
-    str: _make_simple_parser(unicode),  # Иду на поводу у хомячков (FIXME)
-    unicode: _make_simple_parser(unicode),
+    str: _make_simple_parser(six.text_type),  # Иду на поводу у хомячков (FIXME)
+    six.text_type: _make_simple_parser(six.text_type),
     int: _make_simple_parser(int),
     float: _make_simple_parser(float),
     Decimal: _make_simple_parser(Decimal),
@@ -209,6 +208,11 @@ _PARSERS = {
 
 
 #================================== КЛАССЫ ====================================
+
+# "Стражник" для значения по умолчанию ActionContextDeclaration.
+_none = object()
+
+
 class ActionContextDeclaration(object):
     u"""
     Класс, который определяет правило извлечения параметра из
@@ -227,7 +231,7 @@ class ActionContextDeclaration(object):
         необходимо для сообщений об ошибках
     """
     def __init__(
-            self, name='', default=None, type=None,
+            self, name='', default=_none, type=None,
             required=False, verbose_name='', *args, **kwargs):
         assert type, 'type must be defined!'
         self.name = name
@@ -314,8 +318,7 @@ class ActionContext(object):
         key = value = ptype = None
         try:
             # переносим параметры в контекст из запроса
-            for key in request.REQUEST:
-                value = request.REQUEST[key]
+            for key, value in six.iteritems(get_request_params(request)):
                 # Пустые параметры не конвертируем,
                 # т.к. они могут вызвать ошибку
                 if not value:
@@ -331,7 +334,7 @@ class ActionContext(object):
         except IOError as err:
             # В некоторых браузерах (предполагается что в ie)
             # происходит следующие:
-            # request.REQUEST читается и в какой-то момент связь прекращается
+            # REQUEST читается и в какой-то момент связь прекращается
             # из-за того, что браузер разрывает соединение,
             # в следствии этого происходит ошибка
             # IOError: request data read error
@@ -347,7 +350,7 @@ class ActionContext(object):
 
         # переносим обязательные параметры, которые не встретились в запросе
         for rule in rules if rules else []:
-            if rule.required and rule.default is not None and (
+            if rule.required and rule.default is not _none and (
                     not params[rule.name][1]):
                 # если параметр не передан в запросе, но
                 # он является обязательным и задано значение по умолчанию,
@@ -368,7 +371,7 @@ class ActionContext(object):
         if not rules:
             return
         for rule in rules:
-            if rule.required and getattr(self, rule.name, None) is None:
+            if rule.required and getattr(self, rule.name, _none) is _none:
                 raise ActionContext.RequiredFailed(rule.human_name())
 
     def json(self):
@@ -384,7 +387,7 @@ class ActionContext(object):
             elif isinstance(obj, datetime.time):
                 result = _date2str(obj, '%H:%M')
             else:
-                result = force_unicode(obj)
+                result = force_str(obj)
 
             return result
 
@@ -392,7 +395,7 @@ class ActionContext(object):
         # и при этом только те, которые не callable
         data = dict(
             (k, v)
-            for k, v in self.__dict__.iteritems()
+            for k, v in six.iteritems(self.__dict__)
             if not (
                 k.startswith('_') or
                 callable(v)
@@ -440,7 +443,7 @@ class DeclarativeActionContext(ActionContext):
         'int': int,
         'float': float,
         'str': str,
-        'unicode': unicode,
+        'unicode': six.text_type,
         'decimal': Decimal,
 
         # >>> int_or_zero('')
@@ -481,7 +484,7 @@ class DeclarativeActionContext(ActionContext):
         # определяем режим, если правилла описаны парой
         if isinstance(rules, tuple):
             # режим
-            mode = request.REQUEST.get(rules[0])
+            mode = get_request_params(request).get(rules[0])
             try:
                 # правила для конкретного режима
                 rules = rules[1][mode]
@@ -495,7 +498,7 @@ class DeclarativeActionContext(ActionContext):
         errors = []
         only_noncritical = True
 
-        for key, parser_data in rules.iteritems():
+        for key, parser_data in six.iteritems(rules):
             parser = parser_data['type']
             if not callable(parser):
                 try:
@@ -508,7 +511,7 @@ class DeclarativeActionContext(ActionContext):
 
             add_error_to = None
             try:
-                val = request.REQUEST.get(key)
+                val = get_request_params(request).get(key)
                 if val is None:
                     if 'default' in parser_data:
                         val = parser_data['default']
@@ -565,5 +568,5 @@ class DeclarativeActionContext(ActionContext):
         return isinstance(data, dict) or (
             isinstance(data, tuple) and
             len(data) == 2 and
-            isinstance(data[0], basestring)
+            isinstance(data[0], six.string_types)
         )
