@@ -1,25 +1,21 @@
-#coding: utf-8
-"""
-Паки и экшены для работы со справочниками
-+++++++++++++++++++++++++++++++++++++++++
-"""
-from django.db import transaction
+# coding: utf-8
+u"""Паки и экшены для работы со справочниками."""
+
+from __future__ import absolute_import
+from logging import getLogger
+
 from django.conf import settings
-try:
-    from django.utils.log import logger
-except ImportError:
-    from django.utils.log import getLogger
-    logger = getLogger('django')
 
-from m3.actions import (
-    ActionPack, Action, PreJsonResult, OperationResult, ACD
-)
-from m3_ext.ui.misc.store import ExtJsonStore
-from m3_ext.ui.containers import ExtPagingBar
 from m3.actions import utils
 from m3.actions.results import ActionResult
-from m3.db import BaseObjectModel, safe_delete
+from m3.actions.interfaces import ISelectablePack
+from m3.actions import ActionPack, Action, PreJsonResult, OperationResult, ACD
 from m3 import RelatedError
+from m3.db import BaseObjectModel, safe_delete
+from m3_django_compat import get_request_params, atomic
+
+logger = getLogger('django')
+
 
 try:
     from m3_audit import AuditManager
@@ -27,7 +23,6 @@ except ImportError:
     # При сборке документации, внешняя Django ничего не знает про m3_audit
     logger.warning('m3_audit import error')
 
-from m3.actions.interfaces import ISelectablePack
 
 MSG_DOESNOTEXISTS = (
     u'Запись справочника с id=%s не найдена в базе данных.<br/>'
@@ -56,6 +51,9 @@ class DictListWindowAction(Action):
         """
         Создаем и настраиваем окно
         """
+        # Защита от кроссимпорта в http://goo.gl/2u8MJz
+        from m3_ext.ui.containers import ExtPagingBar
+        
         base = self.parent
         allow_copy = hasattr(base, 'allow_copy') and base.allow_copy
         win = base.list_form(mode=mode, title=base.title)
@@ -88,6 +86,9 @@ class DictListWindowAction(Action):
             control.add_column(**column_params)
 
     def configure_list(self, win):
+        # Защита от кроссимпорта в http://goo.gl/2u8MJz
+        from m3_ext.ui.misc.store import ExtJsonStore
+
         base = self.parent
 
         # Устанавливаем источники данных
@@ -239,9 +240,10 @@ class DictRowsAction(Action):
     def run(self, request, context):
         offset = utils.extract_int(request, 'start')
         limit = utils.extract_int(request, 'limit')
-        filter = request.REQUEST.get('filter')
-        direction = request.REQUEST.get('dir')
-        user_sort = request.REQUEST.get('sort')
+        request_params = get_request_params(request)
+        filter = request_params.get('filter')
+        direction = request_params.get('dir')
+        user_sort = request_params.get('sort')
         if direction == 'DESC':
             user_sort = '-' + user_sort
         dict_list = []
@@ -681,7 +683,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
             record = self.model.objects.get(id=id)
         return record
 
-    @transaction.commit_on_success
+    @atomic
     def save_row(self, obj):
         obj.save()
         return OperationResult(success=True)
@@ -690,7 +692,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Такая реализация обусловлена тем,
         # что IntegrityError невозможно отловить
         # до завершения транзакции, и приходится оборачивать транзакцию.
-        @transaction.commit_on_success
+        @atomic
         def delete_row_in_transaction(self, objs):
             message = ''
             if len(objs) == 0:
@@ -702,7 +704,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
                         callable(obj.safe_delete))):
                         try:
                             obj.safe_delete()
-                        except RelatedError, e:
+                        except RelatedError as e:
                             message = e.args[0]
                     else:
                         if not safe_delete(obj):
@@ -714,7 +716,7 @@ class BaseDictionaryModelActions(BaseDictionaryActions):
         # Тут пытаемся поймать ошибку из транзакции.
         try:
             return delete_row_in_transaction(self, objs)
-        except Exception, e:
+        except Exception as e:
             # Встроенный в Django IntegrityError
             # не генерируется. Кидаются исключения
             # специфичные для каждого драйвера БД.
@@ -778,7 +780,7 @@ class BaseEnumerateDictionary(BaseDictionaryActions):
         сам id хранится в БД
         """
         assert isinstance(id, int)
-        assert id in self.enumerate_class.keys(), (
+        assert id in list(self.enumerate_class.keys()), (
             'Enumarate key "%s" is not'
             ' defined in %s' % (id, self.enumerate_class))
         return id
