@@ -1,38 +1,33 @@
 # coding:utf-8
-from __future__ import absolute_import
 
+from __future__ import absolute_import
 import datetime
 
-from django.db import connections
-from django.db import models
-from django.db import router
-from django.db.models.deletion import Collector
+from django.db import models, connection, transaction, router, connections
 from django.db.models.query import QuerySet
-from m3 import RelatedError
-from m3 import json_encode
-from m3_django_compat import Manager
+from django.db.models.deletion import Collector
 from m3_django_compat import commit_unless_managed
+from m3_django_compat import Manager
+
+from m3 import json_encode, RelatedError
 import six
 
 
 def safe_delete(model):
     """
     Функция выполняющая "безопасное" удаление записи из БД.
-
     В случае, если удаление не удалось по причине нарушения целостности,
     то возвращается false. Иначе, true
     к тому же функция пересчитывает MPTT индексы дерева
     т.к. стандартный пересчет запускается при вызове model_instance.delete()
     """
     models.signals.pre_delete.send(sender=model.__class__, instance=model)
-    db_alias = router.db_for_write(model.__class__, instance=model)
     try:
-        connection = connections[db_alias]
         cursor = connection.cursor()
         sql = "DELETE FROM %s WHERE id = %s" % (
             connection.ops.quote_name(model._meta.db_table), model.id)
         cursor.execute(sql)
-        commit_unless_managed(using=db_alias)
+        commit_unless_managed()
     except Exception as e:
         # Встроенный в Django IntegrityError не генерируется.
         # Кидаются исключения, специфичные для каждого драйвера БД.
@@ -45,12 +40,12 @@ def safe_delete(model):
     # (т.к. стандартный пересчет вешается на метод self.delete()
     if hasattr(model, '_tree_manager') and callable(
             getattr(model._tree_manager, '_close_gap', None)):
-        # это, видимо, mptt модель
+        #это, видимо, mptt модель
         opts = model._meta
-        right = getattr(model, getattr(opts, 'right_attr', 'rght'))
-        left = getattr(model, getattr(opts, 'left_attr', 'lft'))
-        tree = getattr(model, getattr(opts, 'tree_id_attr', 'tree_id'))
-        model._tree_manager._close_gap(right - left + 1, right, tree)
+        r = getattr(model, getattr(opts, 'right_attr', 'rght'))
+        l = getattr(model, getattr(opts, 'left_attr', 'lft'))
+        t = getattr(model, getattr(opts, 'tree_id_attr', 'tree_id'))
+        model._tree_manager._close_gap(r - l + 1, r, t)
 
     models.signals.post_delete.send(sender=model.__class__, instance=model)
     return True
@@ -117,7 +112,6 @@ class BaseEnumerate(object):
         return cls.__dict__[name]
 
 
-@six.python_2_unicode_compatible
 class BaseObjectModel(models.Model):
     """
     Базовая модель для объектов системы.
@@ -132,7 +126,7 @@ class BaseObjectModel(models.Model):
         """
         return six.text_type(self)
 
-    def __str__(self):
+    def __unicode__(self):
         """ Определяет текстовое представление объекта """
         name = getattr(self, 'name', None) or getattr(self, 'fullname', None)
         if name:
